@@ -6,12 +6,13 @@ from bouncer.constants import *
 
 
 def ensure(action, subject):
+    request._authorized = True
     current_user = current_app.bouncer.get_current_user()
     ability = Ability(current_user)
     ability.authorization_method = current_app.bouncer.get_authorization_method()
     ability.aliased_actions = current_app.bouncer.alias_actions
     if ability.cannot(action, subject):
-        msg = "{} does not have {} access to {}".format(current_user, action, subject)
+        msg = "{0} does not have {1} access to {2}".format(current_user, action, subject)
         raise Unauthorized(msg)
 
 #alais
@@ -37,12 +38,21 @@ def requires(action, subject):
         return decorated_function
     return decorator
 
+
+def skip_authorization(f):
+    @wraps(f)
+    def decorated_function(*args, **kwargs):
+        request._authorized = True
+        return f(*args, **kwargs)
+    return decorated_function
+
+
 class Bouncer(object):
-    """Thie class is used to control the Abilities Integration to one or more Flask applications"""
+    """This class is used to control the Abilities Integration to one or more Flask applications"""
 
     special_methods = ["get", "put", "patch", "post", "delete", "index"]
 
-    def __init__(self, app):
+    def __init__(self, app, **kwargs):
         self.app = app
         app.bouncer = self
 
@@ -60,6 +70,18 @@ class Bouncer(object):
 
         app.before_request(self.check_implicit_rules)
 
+        if kwargs.get('ensure_authorization', False):
+            app.after_request(self.check_authorization)
+
+
+    def check_authorization(self, response):
+        """checks that an authorization call has been made during the request"""
+        if not hasattr(request, '_authorized'):
+            raise Unauthorized
+        elif not request._authorized:
+            raise Unauthorized
+        return response
+
     def check_implicit_rules(self):
         """ if you are using flask classy are using the standard index,new,put,post, etc ... type routes, we will
             automatically check the permissions for you
